| quickText | R Documentation |
Workhorse function that automatically applies routine text formatting to common expressions and data names used in openair.
quickText(text, auto.text = TRUE, ...)
text |
A character vector. |
auto.text |
A logical option. The default, |
... |
Not used. |
quickText() is routine formatting lookup table. It screens the supplied
character vector text and automatically applies formatting to any
recognised character sub-series. The function is used in a number of
openair functions and can also be used directly by users to format text
components of their own graphs (see below).
The function returns an expression for graphical evaluation.
Karl Ropkins
David Carslaw
Jack Davison
# see axis formatting in an openair plot, e.g.:
scatterPlot(
mydata,
x = "no2",
y = "pm10"
)
# using quickText in other plots
plot(
mydata$no2,
mydata$pm10,
xlab = quickText("my no2 label"),
ylab = quickText("pm10 [ ug.m-3 ]")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.