- mydata
A data frame containing a date field. mydata must contain a
date field in Date or POSIXct format. The input time series must be
regular, e.g., hourly, daily.
- pollutant
The name of a pollutant, e.g., pollutant = "o3". More than one pollutant can be supplied as a vector, e.g., pollutant = c("o3", "nox").
- sigma
The value of sigma to use in the Gaussian.
- type
Used for splitting the data further. Passed to cutData().
- data.thresh
The % data capture threshold. No values are calculated if
data capture over the period of interest is less than this value.
- new.name
The name given to the new column(s). If not supplied it will
create a name based on the name of the pollutant and the averaging period
used.
- date.pad
Should missing dates be padded? Default is FALSE.
- ...
Passed to cutData() for use with type.