TaylorDiagram(mydata, obs = "obs", mod = "mod", group = NULL,
type = "default", normalise = FALSE, layout = NULL,
cols = "brewer1", main = "", ylab = NULL, xlab = NULL,
pch = 20, cex = 2, rms.col = "darkgoldenrod",
cor.col = "black", key = TRUE, key.title = group,
key.columns = 1, key.pos = "bottom", strip = TRUE,
auto.text = TRUE, ...)mod) will be compared.group column is used to differentiate between
different models and can be a factor or character. The total number of
models compared will be equal to the number of unique values of
group.type determines how the data are split
i.e. conditioned, and then plotted. The default is will produce a
single plot using the entire data. Type can be one of the built-in
types as detailed in cutData e.g. "season"mod values by the
layout openColours for more
details). The same line colour can be set for all pollutant
y.x.pch = 1, for
example.columns to be less
than the number of pollutants.lattice:xyplot for more details about
finer control.TRUE (default) or FALSE. If
TRUE titles and axis labels will automatically try and format
pollutant names and units properly e.g. by subscripting the `2' in
NO2.lattice:xyplot and cutData. For example, in the case
of cutData the option hemisphere = "southern".TaylorDiagram also
returns an object of class ``openair''. The object includes three main
components: call, the command used to generate the plot;
data, the data frame of summarised information used to make the
plot; and plot, the plot itself. If retained, e.g. using
output <- TaylorDiagram(thedata, obs = "nox", mod = "mod"),
this output can be used to recover the data, reproduce or rework the
original plot or undertake further analysis. For example,
output$data will be a data frame consisting of the group, type,
correlation coefficient (R), the standard deviation of the
observations and measurements.
An openair output can be manipulated using a number of generic
operations, including print, plot and
summary. See openair.generics for further
details.openair version of the Taylor Diagram has several
enhancements that increase its flexibility. In particular, the
straightforward way of producing conditioning plots should prove
valuable under many circumstances (using the type option). Many
examples of Taylor Diagrams focus on model-observation comparisons for
several models using all the available data. However, more insight can
be gained into model performance by partitioning the data in various
ways e.g. by season, daylight/nighttime, day of the week, by levels of
a numeric variable e.g. wind speed or by land-use type etc.taylor.diagram from the plotrix package from
which some of the annotation code was used.# load openair data if not loaded already
data(mydata)
## first make some dummy data based on year 2000 and call the column 'mod'
testdat <- selectByDate(mydata, year = 2000)
testdat$mod = testdat$nox + 200 * rnorm(1:nrow(testdat))
## basic plot
TaylorDiagram(testdat, obs = "nox", mod = "mod")
## don't have actual model data, but can demonstrate a case with
## multiple models. The code below makes a new column 'month', which
## can be thought of as representing different models. Note also it is
## useful for considering the seasonal performance of a single
## model. Note we choose to normalise the data.
testdat <- cutData(testdat, type = "month")
TaylorDiagram(testdat, obs = "nox", mod = "mod", group = "month",
normalise = TRUE)Run the code above in your browser using DataLab