airbaseInfo(code = "gb0620a", instrument = FALSE)FALSE only one row per site is returned with
other information such as site type, latitude and logitude. When
TRUE details of the individual species and instruments usedinstrument =
TRUE. In this case the species measured at the site together with
the instruments used will be returned.importAirbase,
airbaseFindCode, airbaseStats