aqStats(mydata, pollutant = "no2", data.thresh = 75,
percentile = c(95, 99), transpose = FALSE, ...)date field
of hourly data.pollutant = c("o3", "pm10").data.thresh is
used for example in the calculation of daily mean values
from hourly data. If there are less thatranspose = TRUE then the results have columns for
each pollutant-site combination.transpose appropriately.
Note that the input data is assumed to be in mass units
e.g. ug/m3 for all species except CO (mg/m3).
The following statistics are calculated:
latitudeandlongitudecan also be passed
to this calculation.aqStats function
does not round, whereas AURN data can be rounded at
several stages during the calculations.## Statistics for 2004. NOTE! these data are in ppb/ppm so the
## example is for illustrative purposes only
aqStats(selectByDate(mydata, year = 2004), pollu=c("no2", "pm10"))
## transpose the results:
aqStats(selectByDate(mydata, year = 2004), pollu=c("no2", "pm10"),
transpose = TRUE)Run the code above in your browser using DataLab