| breakOpts | R Documentation |
breaks options for openair plotsThis function provides a convenient way to set default options for breaks
arguments in openair plots, which cut continuous colour scales into
discrete bins.
breakOpts(
breaks = NULL,
labels = NULL,
method = c("number", "interval", "width", "pretty", "wd"),
max.bins = NULL,
include.lowest = NULL,
right = NULL,
dig.lab = NULL
)
breaks, labels |
If a categorical colour scale is required,
By default, |
method |
When
|
max.bins |
If |
include.lowest |
logical, indicating if an |
right |
logical, indicating if the intervals should be closed on the right (and open on the left) or vice versa. |
dig.lab |
Integer which is used when labels are not given. It determines
the number of digits used in formatting the break numbers. If |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.