| colourOpts | R Documentation |
cols options for openair plotsThis function provides a convenient way to set options for customising
colours in openair plots. It returns a list of options that can be passed to
the cols argument of most functions. All arguments are the same as
openColours(), but passing colourOpts() allows each function to set an
appropriate n value and overwrite certain options if required.
colourOpts() and colorOpts() are synonyms.
colourOpts(
scheme = "default",
alpha = 1,
begin = 0,
end = 1,
direction = 1,
saturation = 0.5,
lightness = 0.5
)
colorOpts(
scheme = "default",
alpha = 1,
begin = 0,
end = 1,
direction = 1,
saturation = 0.5,
lightness = 0.5
)
scheme |
Any one of the pre-defined |
alpha |
The alpha transparency level (between |
begin, end |
For sequential schemes, the fraction (between |
direction |
The order of the colours. |
saturation |
The saturation of the colours, between |
lightness |
The lightness of the colours, between |
A list of options that can be passed to the cols argument of
plotting functions like polarPlot().
Other colour functions:
openColours(),
openSchemes()
trendLevel(
mydata,
"no2",
cols = colourOpts("viridis", direction = 1, alpha = 0.5)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.