| openSchemes | R Documentation |
openairThis function returns a table of the available colour schemes in openair,
along with their type (sequential, diverging, or qualitative) and the maximum
number of colours available for that scheme (where applicable). This can be
useful for users to explore the available schemes and to check which schemes
can provide a certain number of colours.
openSchemes(palette_type = c("seq", "div", "qual"), n = NULL)
palette_type |
A character vector specifying which types of palettes to
include in the output. Options are |
n |
An optional whole number to filter the schemes by their maximum
number of colours. Only schemes that can provide at least |
Jack Davison
Other colour functions:
colourOpts(),
openColours()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.