| shared_openair_params | R Documentation |
This is a central place for describing common shared parameters.
This ensures consistency across openair
ws |
The name of the column in |
wd |
The name of the column in |
type |
Character string(s) defining how data should be split/conditioned
before plotting.
Most |
cols |
Colours to use for plotting. Can be a pre-set palette (e.g.,
|
date.breaks |
Number of major x-axis intervals to use. The function will
try and choose a sensible number of dates/times as well as formatting the
date/time appropriately to the range being considered. The user can
override this behaviour by adjusting the value of |
date.format |
This option controls the date format on the x-axis. A
sensible format is chosen by default, but the user can set |
breaks |
|
ref.x |
Either a single value or values representing the x axis
intercepts to draw lines, or a list such as that provided by |
ref.y |
Either a single value or values representing the y axis
intercepts to draw lines, or a list such as that provided by |
angle.scale |
In radial plots (e.g., |
windflow |
If |
offset |
|
limits |
The limits of the colour scale, in the form |
trans |
Should a transformation be applied to the colour scale? If the distribution of data is skewed, the default scale may be dominated by a few high values, so a log or square-root transform may mean the whole colour scale is better presented on the plot. Can be:
|
key.position |
Location where the legend is to be placed. Allowed
arguments include |
key.title |
Used to set the title of the legend. The legend title is
passed to |
key.columns |
Number of columns to be used in a categorical legend. With
many categories a single column can make to key too wide. The user can thus
choose to use several columns by setting |
auto.text |
Either |
plot |
When |
key |
Deprecated; please use |
... |
Addition options are passed on to
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.