| shared_openair_params | R Documentation |
This is a central place for describing common shared parameters.
This ensures consistency across openair
type |
Character string(s) defining how data should be split/conditioned
before plotting.
Most |
cols |
Colours to use for plotting. Can be a pre-set palette (e.g.,
|
date.breaks |
Number of major x-axis intervals to use. The function will
try and choose a sensible number of dates/times as well as formatting the
date/time appropriately to the range being considered. The user can
override this behaviour by adjusting the value of |
date.format |
This option controls the date format on the x-axis. A
sensible format is chosen by default, but the user can set |
breaks, labels |
If a categorical colour scale is required then |
x.relation, y.relation |
This determines how the x- and y-axis scales are
plotted. |
angle.scale |
In radial plots (e.g., |
windflow |
If |
offset |
|
key.position |
Location where the legend is to be placed. Allowed
arguments include |
key.title |
Used to set the title of the legend. The legend title is
passed to |
key.columns |
Number of columns to be used in a categorical legend. With
many categories a single column can make to key too wide. The user can thus
choose to use several columns by setting |
strip.position |
Location where the facet 'strips' are located when
using |
auto.text |
Either |
plot |
When |
key |
Deprecated; please use |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.