| trajLevel | R Documentation |
This function plots gridded back trajectories. This function requires that
data are imported using the importTraj() function.
trajLevel(
mydata,
lon = "lon",
lat = "lat",
pollutant = "height",
type = "default",
smooth = FALSE,
statistic = "frequency",
percentile = 90,
lon.inc = 1,
lat.inc = lon.inc,
min.bin = 1,
.combine = NULL,
sigma = 1.5,
cols = "default",
crs = 4326,
map = TRUE,
map.fill = TRUE,
map.cols = "grey40",
map.border = "black",
map.alpha = 0.3,
map.lwd = 1,
map.lty = 1,
grid.col = "deepskyblue",
grid.nx = 9,
grid.ny = grid.nx,
origin = TRUE,
key.title = NULL,
key.position = "right",
key.columns = NULL,
strip.position = "top",
auto.text = TRUE,
plot = TRUE,
key = NULL,
...
)
mydata |
Data frame, the result of importing a trajectory file using
|
lon, lat |
Columns containing the decimal longitude and latitude. |
pollutant |
Pollutant (or any numeric column) to be plotted, if any.
Alternatively, use |
type |
Character string(s) defining how data should be split/conditioned
before plotting.
Most |
smooth |
Should the trajectory surface be smoothed? |
statistic |
One of:
|
percentile |
The percentile concentration of |
lon.inc, lat.inc |
The longitude and latitude intervals to be used for
binning data. If |
min.bin |
The minimum number of unique points in a grid cell. Counts
below |
.combine |
When statistic is "SQTBA" it is possible to combine lots of
receptor locations to derive a single map. |
sigma |
For the SQTBA approach |
cols |
Colours to use for plotting. Can be a pre-set palette (e.g.,
|
crs |
The coordinate reference system to use for plotting. Defaults to
|
map |
Should a base map be drawn? If |
map.fill |
Should the base map be a filled polygon? Default is to fill countries. |
map.cols |
If |
map.border |
The colour to use for the map outlines/borders. Defaults to
|
map.alpha |
The transparency level of the filled map which takes values from 0 (full transparency) to 1 (full opacity). Setting it below 1 can help view trajectories, trajectory surfaces etc. and a filled base map. |
map.lwd |
The map line width, a positive number, defaulting to |
map.lty |
The map line type. Line types can either be specified as an
integer ( |
grid.col |
The colour of the map grid to be used. To remove the grid set
|
grid.nx, grid.ny |
The approximate number of ticks to draw on the map
grid. |
origin |
If true a filled circle dot is shown to mark the receptor point. |
key.title |
Used to set the title of the legend. The legend title is
passed to |
key.position |
Location where the legend is to be placed. Allowed
arguments include |
key.columns |
Number of columns to be used in a categorical legend. With
many categories a single column can make to key too wide. The user can thus
choose to use several columns by setting |
strip.position |
Location where the facet 'strips' are located when
using |
auto.text |
Either |
plot |
When |
key |
Deprecated; please use |
... |
Addition options are passed on to
|
An alternative way of showing the trajectories compared with plotting
trajectory lines is to bin the points into latitude/longitude intervals. For
these purposes trajLevel() should be used. There are several trajectory
statistics that can be plotted as gridded surfaces. First, statistic can be
set to "frequency" to show the number of back trajectory points in a grid
square. Grid squares are by default at 1 degree intervals, controlled by
lat.inc and lon.inc. Such plots are useful for showing the frequency of
air mass locations. Note that it is also possible to set statistic = "hexbin" for plotting frequencies (not concentrations), which will produce a
plot by hexagonal binning.
If statistic = "difference" the trajectories associated with a
concentration greater than percentile are compared with the the full set of
trajectories to understand the differences in frequencies of the origin of
air masses of the highest concentration trajectories compared with the
trajectories on average. The comparison is made by comparing the percentage
change in gridded frequencies. For example, such a plot could show that the
top 10\
the east.
If statistic = "pscf" then the Potential Source Contribution Function is
plotted. The PSCF calculates the probability that a source is located at
latitude i and longitude j (Pekney et al., 2006).The basis of
PSCF is that if a source is located at (i,j), an air parcel back trajectory
passing through that location indicates that material from the source can be
collected and transported along the trajectory to the receptor site. PSCF
solves
PSCF = m_{ij}/n_{ij}
where n_{ij} is the number of times
that the trajectories passed through the cell (i,j) and m_{ij} is the
number of times that a source concentration was high when the trajectories
passed through the cell (i,j). The criterion for determining m_{ij} is
controlled by percentile, which by default is 90. Note also that cells with
few data have a weighting factor applied to reduce their effect.
A limitation of the PSCF method is that grid cells can have the same PSCF value when sample concentrations are either only slightly higher or much higher than the criterion. As a result, it can be difficult to distinguish moderate sources from strong ones. Seibert et al. (1994) computed concentration fields to identify source areas of pollutants. The Concentration Weighted Trajectory (CWT) approach considers the concentration of a species together with its residence time in a grid cell. The CWT approach has been shown to yield similar results to the PSCF approach. The openair manual has more details and examples of these approaches.
A further useful refinement is to smooth the resulting surface, which is
possible by setting smooth = TRUE.
an openair object
David Carslaw
Jack Davison
Pekney, N. J., Davidson, C. I., Zhou, L., & Hopke, P. K. (2006). Application of PSCF and CPF to PMF-Modeled Sources of PM 2.5 in Pittsburgh. Aerosol Science and Technology, 40(10), 952-961.
Seibert, P., Kromp-Kolb, H., Baltensperger, U., Jost, D., 1994. Trajectory analysis of high-alpine air pollution data. NATO Challenges of Modern Society 18, 595-595.
Xie, Y., & Berkowitz, C. M. (2007). The use of conditional probability functions and potential source contribution functions to identify source regions and advection pathways of hydrocarbon emissions in Houston, Texas. Atmospheric Environment, 41(28), 5831-5847.
Other trajectory analysis functions:
importTraj(),
trajCluster(),
trajPlot()
# show a simple case with no pollutant i.e. just the trajectories
# let's check to see where the trajectories were coming from when
# Heathrow Airport was closed due to the Icelandic volcanic eruption
# 15--21 April 2010.
# import trajectories for London and plot
## Not run:
lond <- importTraj("london", 2010)
## End(Not run)
# more examples to follow linking with concentration measurements...
# import some measurements from KC1 - London
## Not run:
kc1 <- importAURN("kc1", year = 2010)
# now merge with trajectory data by 'date'
lond <- merge(lond, kc1, by = "date")
# trajectory plot, no smoothing - and limit lat/lon area of interest
# use PSCF
trajLevel(subset(lond, lat > 40 & lat < 70 & lon > -20 & lon < 20),
pollutant = "pm10", statistic = "pscf"
)
# can smooth surface, suing CWT approach:
trajLevel(subset(lond, lat > 40 & lat < 70 & lon > -20 & lon < 20),
pollutant = "pm2.5", statistic = "cwt", smooth = TRUE
)
# plot by season:
trajLevel(subset(lond, lat > 40 & lat < 70 & lon > -20 & lon < 20),
pollutant = "pm2.5",
statistic = "pscf", type = "season"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.